package com.ztmap.project.zhny.energystoragecncfdl.service;

import java.util.List;
import com.ztmap.project.zhny.energystoragecncfdl.domain.TEnergyStorageCncfdl;

/**
 * 储能充放电量Service接口
 * 
 * @author ztmap
 * @date 2023-10-09
 */
public interface ITEnergyStorageCncfdlService 
{
    /**
     * 查询储能充放电量
     * 
     * @param id 储能充放电量ID
     * @return 储能充放电量
     */
    public TEnergyStorageCncfdl selectTEnergyStorageCncfdlById(Long id);

    /**
     * 查询储能充放电量列表
     * 
     * @param tEnergyStorageCncfdl 储能充放电量
     * @return 储能充放电量集合
     */
    public List<TEnergyStorageCncfdl> selectTEnergyStorageCncfdlList(TEnergyStorageCncfdl tEnergyStorageCncfdl);

    /**
     * 新增储能充放电量
     * 
     * @param tEnergyStorageCncfdl 储能充放电量
     * @return 结果
     */
    public int insertTEnergyStorageCncfdl(TEnergyStorageCncfdl tEnergyStorageCncfdl);

    /**
     * 修改储能充放电量
     * 
     * @param tEnergyStorageCncfdl 储能充放电量
     * @return 结果
     */
    public int updateTEnergyStorageCncfdl(TEnergyStorageCncfdl tEnergyStorageCncfdl);

    /**
     * 批量删除储能充放电量
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteTEnergyStorageCncfdlByIds(String ids);

    /**
     * 删除储能充放电量信息
     * 
     * @param id 储能充放电量ID
     * @return 结果
     */
    public int deleteTEnergyStorageCncfdlById(Long id);
}
